#!/usr/bin/perl

use warnings;
use strict;
use lib('tlpkg', '/usr/share/tlpkg');
use Getopt::Std;

use TeXLive::TLConfig;
use TeXLive::TLPDB;

if (! -f "/usr/share/tlpkg/texlive.tlpdb") {
    `wget http://mirrors.ctan.org/systems/texlive/tlnet/tlpkg/texlive.tlpdb.xz`;
    `sudo sh -c "xz -d < texlive.tlpdb.xz > /usr/share/tlpkg/texlive.tlpdb"`;
}

my $tlpdb = TeXLive::TLPDB->new(root => "/usr/share");

my $arch = `uname -m`;
chomp($arch);
$arch = "i386" if ($arch =~ m/i[456]86/);
$arch .= "-linux";
unless (grep($arch, $tlpdb->available_architectures)) {
    die("missing architecture $arch\n");
}

chomp(my $enable_asymptote = `rpm --eval "%{_texmf_enable_asymptote}"`);
chomp(my $enable_xindy = `rpm --eval "%{_texmf_enable_xindy}"`);
chomp(my $with_system_lcdf = `rpm --eval "%{_texmf_with_system_lcdf}"`);
chomp(my $with_system_psutils = `rpm --eval "%{_texmf_with_system_psutils}"`);
chomp(my $with_system_t1lib = `rpm --eval "%{_texmf_with_system_t1lib}"`);

my %options;
my $error = 0;
Getopt::Std::getopts("?hiu", \%options) or $error = 1;
if ($#ARGV >= 0 or $error or $options{'h'} or $options{'?'}) {
    print("$0 [-ih?]\n",
	  "-u		Update texlive.tlpdb\n",
	  "-i		Initialize (checkout missing packages).\n",
	  "-h, -?	Prints this help message and exists.\n");
    exit(0);
}

if ($options{'u'}) {
    `wget http://mirrors.ctan.org/systems/texlive/tlnet/tlpkg/texlive.tlpdb.xz`;
    #`wget http://linorg.usp.br/CTAN/systems/texlive/tlnet/tlpkg/texlive.tlpdb.xz`;
    if ($?) {
	die("failed to donwload texlive.tlpdb.xz\n");
    }
    `sudo sh -c "xz -d < texlive.tlpdb.xz > /usr/share/tlpkg/texlive.tlpdb"`;
    if ($?) {
	die("failed unpack texlive.tlpdb under /usr/share/tlpkg\n");
    }
}

# Check what is in svn
my %namerev = (
    # Manually initialize these due to special case packaging
    "cyrillic-bin"				=>	"29764",
    "latex-bin"					=>	"29764",
);

my @dirlist = (
    "texlive-12many",
    "texlive-2up",
    "texlive-Asana-Math",
    "texlive-ESIEEcv",
    "texlive-FAQ-en",
    "texlive-GS1",
    "texlive-HA-prosper",
    "texlive-IEEEconf",
    "texlive-IEEEtran",
    "texlive-MemoirChapStyles",
    "texlive-SIstyle",
    "texlive-SIunits",
    "texlive-Tabbing",
    "texlive-Type1fonts",
    "texlive-a0poster",
    "texlive-a2ping",
    "texlive-a4wide",
    "texlive-a5comb",
    "texlive-aastex",
    "texlive-abbr",
    "texlive-abc",
    "texlive-abntex2",
    "texlive-abraces",
    "texlive-abstract",
    "texlive-abstyles",
    "texlive-accanthis",
    "texlive-accfonts",
    "texlive-achemso",
    "texlive-acmconf",
    "texlive-acro",
    "texlive-acronym",
    "texlive-acroterm",
    "texlive-active-conf",
    "texlive-actuarialangle",
    "texlive-addlines",
    "texlive-adfathesis",
    "texlive-adforn",
    "texlive-adfsymbols",
    "texlive-adhocfilelist",
    "texlive-adjmulticol",
    "texlive-adjustbox",
    "texlive-adobemapping",
    "texlive-adrconv",
    "texlive-advdate",
    "texlive-ae",
    "texlive-aecc",
    "texlive-aeguill",
    "texlive-afm2pl",
    "texlive-afthesis",
    "texlive-aguplus",
    "texlive-aiaa",
    "texlive-aichej",
    "texlive-akktex",
    "texlive-akletter",
    "texlive-alegreya",
    "texlive-aleph",
    "texlive-alg",
    "texlive-algorithm2e",
    "texlive-algorithmicx",
    "texlive-algorithms",
    "texlive-allrunes",
    "texlive-alnumsec",
    "texlive-alterqcm",
    "texlive-altfont",
    "texlive-ametsoc",
    "texlive-amiri",
    "texlive-amsaddr",
    "texlive-amscls",
    "texlive-amsfonts",
    "texlive-amslatex-primer",
    "texlive-amsldoc-it",
    "texlive-amsldoc-vn",
    "texlive-amsmath",
    "texlive-amsmath-it",
    "texlive-amsrefs",
    "texlive-amstex",
    "texlive-amsthdoc-it",
    "texlive-animate",
    "texlive-anonchap",
    "texlive-answers",
    "texlive-antiqua",
    "texlive-antomega",
    "texlive-antt",
    "texlive-anufinalexam",
    "texlive-anyfontsize",
    "texlive-anysize",
    "texlive-aomart",
    "texlive-apa",
    "texlive-apa6",
    "texlive-apa6e",
    "texlive-apacite",
    "texlive-apalike2",
    "texlive-appendix",
    "texlive-appendixnumberbeamer",
    "texlive-apprends-latex",
    "texlive-apptools",
    "texlive-arabi",
    "texlive-arabtex",
    "texlive-arabxetex",
    "texlive-aramaic-serto",
    "texlive-arara",
    "texlive-archaic",
    "texlive-arcs",
    "texlive-arev",
    "texlive-around-the-bend",
    "texlive-arphic",
    "texlive-arrayjobx",
    "texlive-arraysort",
    "texlive-arsclassica",
    "texlive-articleingud",
    "texlive-arydshln",
    "texlive-asaetr",
    "texlive-ascelike",
    "texlive-ascii",
    "texlive-ascii-chart",
    "texlive-ascii-font",
    "texlive-aspectratio",
    "texlive-assignment",
    "texlive-astro",
    "texlive-asyfig",
    "texlive-attachfile",
    "texlive-augie",
    "texlive-auncial-new",
    "texlive-aurical",
    "texlive-authoraftertitle",
    "texlive-authorindex",
    "texlive-auto-pst-pdf",
    "texlive-autoarea",
    "texlive-automata",
    "texlive-autonum",
    "texlive-autopdf",
    "texlive-avantgar",
    "texlive-b1encoding",
    "texlive-babel",
    "texlive-babel-albanian",
    "texlive-babel-bahasa",
    "texlive-babel-basque",
    "texlive-babel-breton",
    "texlive-babel-bulgarian",
    "texlive-babel-catalan",
    "texlive-babel-croatian",
    "texlive-babel-czech",
    "texlive-babel-danish",
    "texlive-babel-dutch",
    "texlive-babel-english",
    "texlive-babel-esperanto",
    "texlive-babel-estonian",
    "texlive-babel-finnish",
    "texlive-babel-french",
    "texlive-babel-friulan",
    "texlive-babel-galician",
    "texlive-babel-georgian",
    "texlive-babel-german",
    "texlive-babel-greek",
    "texlive-babel-hebrew",
    "texlive-babel-hungarian",
    "texlive-babel-icelandic",
    "texlive-babel-interlingua",
    "texlive-babel-irish",
    "texlive-babel-italian",
    "texlive-babel-kurmanji",
    "texlive-babel-latin",
    "texlive-babel-norsk",
    "texlive-babel-piedmontese",
    "texlive-babel-polish",
    "texlive-babel-portuges",
    "texlive-babel-romanian",
    "texlive-babel-romansh",
    "texlive-babel-russian",
    "texlive-babel-samin",
    "texlive-babel-scottish",
    "texlive-babel-serbian",
    "texlive-babel-serbianc",
    "texlive-babel-slovak",
    "texlive-babel-slovenian",
    "texlive-babel-sorbian",
    "texlive-babel-spanish",
    "texlive-babel-swedish",
    "texlive-babel-thai",
    "texlive-babel-turkish",
    "texlive-babel-ukraineb",
    "texlive-babel-vietnamese",
    "texlive-babel-welsh",
    "texlive-babelbib",
    "texlive-background",
    "texlive-backnaur",
    "texlive-bangtex",
    "texlive-barcodes",
    "texlive-bardiag",
    "texlive-barr",
    "texlive-bartel-chess-fonts",
    "texlive-bashful",
    "texlive-baskervald",
    "texlive-basque-book",
    "texlive-basque-date",
    "texlive-bbcard",
    "texlive-bbding",
    "texlive-bbm",
    "texlive-bbm-macros",
    "texlive-bbold",
    "texlive-bbold-type1",
    "texlive-bchart",
    "texlive-bclogo",
    "texlive-beamer",
    "texlive-beamer-FUBerlin",
    "texlive-beamer-tut-pt",
    "texlive-beamer2thesis",
    "texlive-beameraudience",
    "texlive-beamerposter",
    "texlive-beamersubframe",
    "texlive-beamertheme-upenn-bc",
    "texlive-beamerthemejltree",
    "texlive-beamerthemenirma",
    "texlive-beamerthemephnompenh",
    "texlive-beebe",
    "texlive-begriff",
    "texlive-belleek",
    "texlive-bengali",
    "texlive-bera",
    "texlive-berenisadf",
    "texlive-besjournals",
    "texlive-betababel",
    "texlive-beton",
    "texlive-bez123",
    "texlive-bezos",
    "texlive-bgreek",
    "texlive-bgteubner",
    "texlive-bguq",
    "texlive-bhcexam",
    "texlive-bib-fr",
    "texlive-bibarts",
    "texlive-biber",
    "texlive-bibexport",
    "texlive-bibhtml",
    "texlive-biblatex",
    "texlive-biblatex-apa",
    "texlive-biblatex-bwl",
    "texlive-biblatex-caspervector",
    "texlive-biblatex-chem",
    "texlive-biblatex-chicago",
    "texlive-biblatex-dw",
    "texlive-biblatex-fiwi",
    "texlive-biblatex-gost",
    "texlive-biblatex-historian",
    "texlive-biblatex-ieee",
    "texlive-biblatex-juradiss",
    "texlive-biblatex-luh-ipw",
    "texlive-biblatex-mla",
    "texlive-biblatex-musuos",
    "texlive-biblatex-nature",
    "texlive-biblatex-nejm",
    "texlive-biblatex-philosophy",
    "texlive-biblatex-phys",
    "texlive-biblatex-publist",
    "texlive-biblatex-science",
    "texlive-biblatex-swiss-legal",
    "texlive-biblatex-trad",
    "texlive-bibleref",
    "texlive-bibleref-french",
    "texlive-bibleref-german",
    "texlive-bibleref-lds",
    "texlive-bibleref-mouth",
    "texlive-bibleref-parse",
    "texlive-biblist",
    "texlive-bibtex",
    "texlive-bibtex8",
    "texlive-bibtexu",
    "texlive-bibtopic",
    "texlive-bibtopicprefix",
    "texlive-bibunits",
    "texlive-bidi",
    "texlive-bigfoot",
    "texlive-bigints",
    "texlive-binomexp",
    "texlive-biocon",
    "texlive-biolinum-type1",
    "texlive-bitelist",
    "texlive-bizcard",
    "texlive-blacklettert1",
    "texlive-blindtext",
    "texlive-blkarray",
    "texlive-block",
    "texlive-blockdraw_mp",
    "texlive-bloques",
    "texlive-blowup",
    "texlive-bodegraph",
    "texlive-bohr",
    "texlive-boisik",
    "texlive-boites",
    "texlive-bold-extra",
    "texlive-boldtensors",
    "texlive-bondgraph",
    "texlive-bookest",
    "texlive-bookhands",
    "texlive-booklet",
    "texlive-bookman",
    "texlive-booktabs",
    "texlive-booktabs-de",
    "texlive-booktabs-fr",
    "texlive-boolexpr",
    "texlive-boondox",
    "texlive-bophook",
    "texlive-borceux",
    "texlive-bosisio",
    "texlive-boxedminipage",
    "texlive-boxhandler",
    "texlive-bpchem",
    "texlive-bpolynomial",
    "texlive-bracketkey",
    "texlive-braids",
    "texlive-braille",
    "texlive-braket",
    "texlive-brandeis-dissertation",
    "texlive-breakcites",
    "texlive-breakurl",
    "texlive-bropd",
    "texlive-brushscr",
    "texlive-bullcntr",
    "texlive-bundledoc",
    "texlive-burmese",
    "texlive-bussproofs",
    "texlive-bxbase",
    "texlive-bxcjkjatype",
    "texlive-bxdpx-beamer",
    "texlive-bxeepic",
    "texlive-bxjscls",
    "texlive-bytefield",
    "texlive-c-pascal",
    "texlive-c90",
    "texlive-cabin",
    "texlive-cachepic",
    "texlive-calcage",
    "texlive-calctab",
    "texlive-calculator",
    "texlive-calligra",
    "texlive-calligra-type1",
    "texlive-calrsfs",
    "texlive-cals",
    "texlive-calxxxx-yyyy",
    "texlive-cancel",
    "texlive-canoniclayout",
    "texlive-cantarell",
    "texlive-capt-of",
    "texlive-captcont",
    "texlive-captdef",
    "texlive-caption",
    "texlive-carlisle",
    "texlive-carolmin-ps",
    "texlive-cascadilla",
    "texlive-cases",
    "texlive-casyl",
    "texlive-catchfilebetweentags",
    "texlive-catcodes",
    "texlive-catechis",
    "texlive-catoptions",
    "texlive-cbcoptic",
    "texlive-cbfonts",
    "texlive-cbfonts-fd",
    "texlive-cc-pl",
    "texlive-ccaption",
    "texlive-ccfonts",
    "texlive-ccicons",
    "texlive-cclicenses",
    "texlive-cd",
    "texlive-cd-cover",
    "texlive-cdpbundl",
    "texlive-cell",
    "texlive-cellspace",
    "texlive-censor",
    "texlive-cfr-lm",
    "texlive-changebar",
    "texlive-changelayout",
    "texlive-changepage",
    "texlive-changes",
    "texlive-chappg",
    "texlive-chapterfolder",
    "texlive-charter",
    "texlive-chbibref",
    "texlive-checkcites",
    "texlive-chem-journal",
    "texlive-chemarrow",
    "texlive-chembst",
    "texlive-chemcompounds",
    "texlive-chemcono",
    "texlive-chemexec",
    "texlive-chemfig",
    "texlive-chemmacros",
    "texlive-chemnum",
    "texlive-chemstyle",
    "texlive-cherokee",
    "texlive-chess",
    "texlive-chess-problem-diagrams",
    "texlive-chessboard",
    "texlive-chessfss",
    "texlive-chet",
    "texlive-chextras",
    "texlive-chicago",
    "texlive-chicago-annote",
    "texlive-chickenize",
    "texlive-chkfloat",
    "texlive-chktex",
    "texlive-chletter",
    "texlive-chngcntr",
    "texlive-chronology",
    "texlive-chronosys",
    "texlive-chscite",
    "texlive-circ",
    "texlive-circuitikz",
    "texlive-cite",
    "texlive-cjhebrew",
    "texlive-cjk",
    "texlive-cjk-ko",
    "texlive-cjkpunct",
    "texlive-cjkutils",
    "texlive-classics",
    "texlive-classicthesis",
    "texlive-clefval",
    "texlive-cleveref",
    "texlive-clipboard",
    "texlive-clock",
    "texlive-clrscode",
    "texlive-cm",
    "texlive-cm-lgc",
    "texlive-cm-super",
    "texlive-cm-unicode",
    "texlive-cmap",
    "texlive-cmarrows",
    "texlive-cmbright",
    "texlive-cmcyr",
    "texlive-cmdstring",
    "texlive-cmdtrack",
    "texlive-cmextra",
    "texlive-cmll",
    "texlive-cmpica",
    "texlive-cmpj",
    "texlive-cmsd",
    "texlive-cmtiup",
    "texlive-cnltx",
    "texlive-cns",
    "texlive-codedoc",
    "texlive-codepage",
    "texlive-codicefiscaleitaliano",
    "texlive-collcell",
    "texlive-collectbox",
    "texlive-collection-basic",
    "texlive-collection-bibtexextra",
    "texlive-collection-binextra",
    "texlive-collection-context",
    "texlive-collection-documentation-arabic",
    "texlive-collection-documentation-base",
    "texlive-collection-documentation-bulgarian",
    "texlive-collection-documentation-chinese",
    "texlive-collection-documentation-czechslovak",
    "texlive-collection-documentation-dutch",
    "texlive-collection-documentation-english",
    "texlive-collection-documentation-finnish",
    "texlive-collection-documentation-french",
    "texlive-collection-documentation-german",
    "texlive-collection-documentation-italian",
    "texlive-collection-documentation-japanese",
    "texlive-collection-documentation-korean",
    "texlive-collection-documentation-mongolian",
    "texlive-collection-documentation-polish",
    "texlive-collection-documentation-portuguese",
    "texlive-collection-documentation-russian",
    "texlive-collection-documentation-serbian",
    "texlive-collection-documentation-slovenian",
    "texlive-collection-documentation-spanish",
    "texlive-collection-documentation-thai",
    "texlive-collection-documentation-turkish",
    "texlive-collection-documentation-ukrainian",
    "texlive-collection-documentation-vietnamese",
    "texlive-collection-fontsextra",
    "texlive-collection-fontsrecommended",
    "texlive-collection-fontutils",
    "texlive-collection-formatsextra",
    "texlive-collection-games",
    "texlive-collection-genericextra",
    "texlive-collection-genericrecommended",
    "texlive-collection-htmlxml",
    "texlive-collection-humanities",
    "texlive-collection-langafrican",
    "texlive-collection-langarabic",
    "texlive-collection-langarmenian",
    "texlive-collection-langcjk",
    "texlive-collection-langcroatian",
    "texlive-collection-langcyrillic",
    "texlive-collection-langczechslovak",
    "texlive-collection-langdanish",
    "texlive-collection-langdutch",
    "texlive-collection-langenglish",
    "texlive-collection-langeuropean",
    "texlive-collection-langfinnish",
    "texlive-collection-langfrench",
    "texlive-collection-langgerman",
    "texlive-collection-langgreek",
    "texlive-collection-langhebrew",
    "texlive-collection-langhungarian",
    "texlive-collection-langindic",
    "texlive-collection-langitalian",
    "texlive-collection-langlatin",
    "texlive-collection-langlatvian",
    "texlive-collection-langlithuanian",
    "texlive-collection-langmongolian",
    "texlive-collection-langnorwegian",
    "texlive-collection-langother",
    "texlive-collection-langpolish",
    "texlive-collection-langportuguese",
    "texlive-collection-langspanish",
    "texlive-collection-langswedish",
    "texlive-collection-langtibetan",
    "texlive-collection-langturkmen",
    "texlive-collection-langvietnamese",
    "texlive-collection-latex",
    "texlive-collection-latexextra",
    "texlive-collection-latexrecommended",
    "texlive-collection-luatex",
    "texlive-collection-mathextra",
    "texlive-collection-metapost",
    "texlive-collection-music",
    "texlive-collection-omega",
    "texlive-collection-pictures",
    "texlive-collection-plainextra",
    "texlive-collection-pstricks",
    "texlive-collection-publishers",
    "texlive-collection-science",
    "texlive-collection-texinfo",
    "texlive-collection-xetex",
    "texlive-collref",
    "texlive-colordoc",
    "texlive-colorinfo",
    "texlive-colorsep",
    "texlive-colortab",
    "texlive-colortbl",
    "texlive-colorwav",
    "texlive-colorweb",
    "texlive-colourchange",
    "texlive-combelow",
    "texlive-combine",
    "texlive-combinedgraphics",
    "texlive-comfortaa",
    "texlive-comma",
    "texlive-commado",
    "texlive-commath",
    "texlive-comment",
    "texlive-compactbib",
    "texlive-complexity",
    "texlive-components-of-TeX",
    "texlive-comprehensive",
    "texlive-computational-complexity",
    "texlive-concepts",
    "texlive-concmath",
    "texlive-concmath-fonts",
    "texlive-concprog",
    "texlive-concrete",
    "texlive-confproc",
    "texlive-constants",
    "texlive-conteq",
    "texlive-context",
    "texlive-context-account",
    "texlive-context-algorithmic",
    "texlive-context-bnf",
    "texlive-context-chromato",
    "texlive-context-construction-plan",
    "texlive-context-cyrillicnumbers",
    "texlive-context-degrade",
    "texlive-context-filter",
    "texlive-context-fixme",
    "texlive-context-french",
    "texlive-context-fullpage",
    "texlive-context-games",
    "texlive-context-gantt",
    "texlive-context-gnuplot",
    "texlive-context-letter",
    "texlive-context-lettrine",
    "texlive-context-lilypond",
    "texlive-context-mathsets",
    "texlive-context-notes-zh-cn",
    "texlive-context-rst",
    "texlive-context-ruby",
    "texlive-context-simplefonts",
    "texlive-context-simpleslides",
    "texlive-context-transliterator",
    "texlive-context-typearea",
    "texlive-context-typescripts",
    "texlive-context-vim",
    "texlive-contour",
    "texlive-contracard",
    "texlive-convbkmk",
    "texlive-cooking",
    "texlive-cookingsymbols",
    "texlive-cool",
    "texlive-coollist",
    "texlive-coolstr",
    "texlive-coolthms",
    "texlive-cooltooltips",
    "texlive-coordsys",
    "texlive-copyrightbox",
    "texlive-coseoul",
    "texlive-countriesofeurope",
    "texlive-counttexruns",
    "texlive-courier",
    "texlive-courier-scaled",
    "texlive-courseoutline",
    "texlive-coursepaper",
    "texlive-coverpage",
    "texlive-covington",
    "texlive-cprotect",
    "texlive-crbox",
    "texlive-crop",
    "texlive-crossreference",
    "texlive-crossword",
    "texlive-crosswrd",
    "texlive-cryst",
    "texlive-cs",
    "texlive-csbulletin",
    "texlive-cslatex",
    "texlive-csplain",
    "texlive-csquotes",
    "texlive-csquotes-de",
    "texlive-cstex",
    "texlive-csvsimple",
    "texlive-csvtools",
    "texlive-ctable",
    "texlive-ctanify",
    "texlive-ctanupload",
    "texlive-ctex",
    "texlive-ctex-faq",
    "texlive-ctib",
    "texlive-ctie",
    "texlive-cuisine",
    "texlive-currfile",
    "texlive-currvita",
    "texlive-cursolatex",
    "texlive-curve",
    "texlive-curve2e",
    "texlive-curves",
    "texlive-custom-bib",
    "texlive-cutwin",
    "texlive-cv",
    "texlive-cweb",
    "texlive-cweb-latex",
    "texlive-cyklop",
    "texlive-cyrillic",
    "texlive-cyrplain",
    "texlive-dancers",
    "texlive-dashbox",
    "texlive-dashrule",
    "texlive-dashundergaps",
    "texlive-datatool",
    "texlive-dateiliste",
    "texlive-datenumber",
    "texlive-datetime",
    "texlive-dblfloatfix",
    "texlive-dcpic",
    "texlive-de-macro",
    "texlive-decimal",
    "texlive-decorule",
    "texlive-dehyph-exptl",
    "texlive-dejavu",
    "texlive-delim",
    "texlive-delimtxt",
    "texlive-detex",
    "texlive-devnag",
    "texlive-dhua",
    "texlive-diagbox",
    "texlive-diagmac2",
    "texlive-diagnose",
    "texlive-dialogl",
    "texlive-dice",
    "texlive-dichokey",
    "texlive-dictsym",
    "texlive-digiconfigs",
    "texlive-din1505",
    "texlive-dinat",
    "texlive-dinbrief",
    "texlive-dingbat",
    "texlive-directory",
    "texlive-dirtree",
    "texlive-dirtytalk",
    "texlive-disser",
    "texlive-dk-bib",
    "texlive-dlfltxb",
    "texlive-dnaseq",
    "texlive-dnp",
    "texlive-doc-pictex",
    "texlive-docmfp",
    "texlive-docmute",
    "texlive-documentation",
    "texlive-doi",
    "texlive-doipubmed",
    "texlive-dosepsbin",
    "texlive-dot2texi",
    "texlive-dotarrow",
    "texlive-dotseqn",
    "texlive-dottex",
    "texlive-doublestroke",
    "texlive-dowith",
    "texlive-download",
    "texlive-dox",
    "texlive-dozenal",
    "texlive-dpfloat",
    "texlive-dprogress",
    "texlive-drac",
    "texlive-draftcopy",
    "texlive-draftwatermark",
    "texlive-dramatist",
    "texlive-dratex",
    "texlive-drawstack",
    "texlive-droid",
    "texlive-droit-fr",
    "texlive-drs",
    "texlive-drv",
    "texlive-dtk",
    "texlive-dtl",
    "texlive-dtxgallery",
    "texlive-dtxgen",
    "texlive-dtxtut",
    "texlive-duerer",
    "texlive-duerer-latex",
    "texlive-duotenzor",
    "texlive-dutchcal",
    "texlive-dvdcoll",
    "texlive-dvgloss",
    "texlive-dvi2tty",
    "texlive-dviasm",
    "texlive-dvicopy",
    "texlive-dvidvi",
    "texlive-dviincl",
    "texlive-dviljk",
    "texlive-dvipdfm",
    "texlive-dvipdfmx",
    "texlive-dvipdfmx-def",
    "texlive-dvipng",
    "texlive-dvipos",
    "texlive-dvips",
    "texlive-dvipsconfig",
    "texlive-dvisvgm",
    "texlive-dynblocks",
    "texlive-dyntree",
    "texlive-ean",
    "texlive-ean13isbn",
    "texlive-easy",
    "texlive-easy-todo",
    "texlive-easyfig",
    "texlive-easylist",
    "texlive-ebezier",
    "texlive-ebgaramond",
    "texlive-ebong",
    "texlive-ebook",
    "texlive-ebsthesis",
    "texlive-ec",
    "texlive-ecc",
    "texlive-ecclesiastic",
    "texlive-ecltree",
    "texlive-eco",
    "texlive-economic",
    "texlive-ecv",
    "texlive-ed",
    "texlive-edfnotes",
    "texlive-edmac",
    "texlive-edmargin",
    "texlive-ednotes",
    "texlive-eemeir",
    "texlive-eepic",
    "texlive-egameps",
    "texlive-egplot",
    "texlive-eiad",
    "texlive-eiad-ltx",
    "texlive-eijkhout",
    "texlive-einfuehrung",
    "texlive-ejpecp",
    "texlive-elbioimp",
    "texlive-electrum",
    "texlive-eledform",
    "texlive-eledmac",
    "texlive-ellipsis",
    "texlive-elmath",
    "texlive-elpres",
    "texlive-elsarticle",
    "texlive-elteikthesis",
    "texlive-eltex",
    "texlive-elvish",
    "texlive-emarks",
    "texlive-embedall",
    "texlive-embrac",
    "texlive-emp",
    "texlive-emptypage",
    "texlive-emulateapj",
    "texlive-enctex",
    "texlive-encxvlna",
    "texlive-endfloat",
    "texlive-endheads",
    "texlive-endiagram",
    "texlive-endnotes",
    "texlive-engpron",
    "texlive-engrec",
    "texlive-engtlc",
    "texlive-enigma",
    "texlive-enotez",
    "texlive-enumitem",
    "texlive-enumitem-zref",
    "texlive-envbig",
    "texlive-environ",
    "texlive-envlab",
    "texlive-epigrafica",
    "texlive-epigram",
    "texlive-epigraph",
    "texlive-epiolmec",
    "texlive-eplain",
    "texlive-epsdice",
    "texlive-epsf",
    "texlive-epsincl",
    "texlive-epslatex-fr",
    "texlive-epspdf",
    "texlive-epspdfconversion",
    "texlive-epstopdf",
    "texlive-eqell",
    "texlive-eqlist",
    "texlive-eqname",
    "texlive-eqnarray",
    "texlive-eqparbox",
    "texlive-erdc",
    "texlive-errata",
    "texlive-es-tex-faq",
    "texlive-esami",
    "texlive-esdiff",
    "texlive-esint",
    "texlive-esint-type1",
    "texlive-esk",
    "texlive-eskd",
    "texlive-eskdx",
    "texlive-eso-pic",
    "texlive-esstix",
    "texlive-estcpmm",
    "texlive-esvect",
    "texlive-etaremune",
    "texlive-etex",
    "texlive-etex-pkg",
    "texlive-etextools",
    "texlive-ethiop",
    "texlive-ethiop-t1",
    "texlive-etoc",
    "texlive-etoolbox",
    "texlive-etoolbox-de",
    "texlive-euenc",
    "texlive-eukdate",
    "texlive-euler",
    "texlive-eulervm",
    "texlive-euro",
    "texlive-euro-ce",
    "texlive-europecv",
    "texlive-eurosym",
    "texlive-euxm",
    "texlive-everyhook",
    "texlive-everypage",
    "texlive-exam",
    "texlive-examdesign",
    "texlive-examplep",
    "texlive-exceltex",
    "texlive-excludeonly",
    "texlive-exercise",
    "texlive-exp-testopt",
    "texlive-expdlist",
    "texlive-expex",
    "texlive-export",
    "texlive-expressg",
    "texlive-exsheets",
    "texlive-exsol",
    "texlive-extarrows",
    "texlive-exteps",
    "texlive-extpfeil",
    "texlive-extract",
    "texlive-extsizes",
    "texlive-facsimile",
    "texlive-factura",
    "texlive-facture",
    "texlive-faktor",
    "texlive-fancybox",
    "texlive-fancyhdr",
    "texlive-fancyhdr-it",
    "texlive-fancynum",
    "texlive-fancypar",
    "texlive-fancyref",
    "texlive-fancytabs",
    "texlive-fancytooltips",
    "texlive-fancyvrb",
    "texlive-fandol",
    "texlive-fast-diagram",
    "texlive-fbb",
    "texlive-fbithesis",
    "texlive-fbs",
    "texlive-fc",
    "texlive-fcltxdoc",
    "texlive-fdsymbol",
    "texlive-featpost",
    "texlive-fenixpar",
    "texlive-feupphdteses",
    "texlive-feyn",
    "texlive-feynmf",
    "texlive-feynmp-auto",
    "texlive-fge",
    "texlive-fifinddo-info",
    "texlive-fig4latex",
    "texlive-figbas",
    "texlive-figbib",
    "texlive-figflow",
    "texlive-figsize",
    "texlive-filecontents",
    "texlive-filedate",
    "texlive-filehook",
    "texlive-fileinfo",
    "texlive-filemod",
    "texlive-finbib",
    "texlive-findhyph",
    "texlive-fink",
    "texlive-finstrut",
    "texlive-first-latex-doc",
    "texlive-fix2col",
    "texlive-fixfoot",
    "texlive-fixlatvian",
    "texlive-fixltxhyph",
    "texlive-fixme",
    "texlive-fixmetodonotes",
    "texlive-fixpdfmag",
    "texlive-fjodor",
    "texlive-flabels",
    "texlive-flacards",
    "texlive-flagderiv",
    "texlive-flashcards",
    "texlive-flashmovie",
    "texlive-flipbook",
    "texlive-flippdf",
    "texlive-float",
    "texlive-floatflt",
    "texlive-floatrow",
    "texlive-flowchart",
    "texlive-flowfram",
    "texlive-fltpoint",
    "texlive-fmp",
    "texlive-fmtcount",
    "texlive-fn2end",
    "texlive-fnbreak",
    "texlive-fncychap",
    "texlive-fncylab",
    "texlive-fnpara",
    "texlive-fnpct",
    "texlive-fntproof",
    "texlive-fnumprint",
    "texlive-foekfont",
    "texlive-foilhtml",
    "texlive-fonetika",
    "texlive-font-change",
    "texlive-fontawesome",
    "texlive-fontaxes",
    "texlive-fontbook",
    "texlive-fontch",
    "texlive-fontinst",
    "texlive-fontname",
    "texlive-fontools",
    "texlive-fonts-tlwg",
    "texlive-fontspec",
    "texlive-fonttable",
    "texlive-fontware",
    "texlive-fontwrap",
    "texlive-footbib",
    "texlive-footmisc",
    "texlive-footnotebackref",
    "texlive-footnoterange",
    "texlive-footnpag",
    "texlive-forarray",
    "texlive-foreign",
    "texlive-forest",
    "texlive-forloop",
    "texlive-formlett",
    "texlive-formular",
    "texlive-fouridx",
    "texlive-fourier",
    "texlive-fouriernc",
    "texlive-fp",
    "texlive-fpl",
    "texlive-fragmaster",
    "texlive-fragments",
    "texlive-frame",
    "texlive-framed",
    "texlive-francais-bst",
    "texlive-frankenstein",
    "texlive-frcursive",
    "texlive-frege",
    "texlive-frenchle",
    "texlive-friulan",
    "texlive-frletter",
    "texlive-frontespizio",
    "texlive-ftcap",
    "texlive-ftnxtra",
    "texlive-fullblck",
    "texlive-fullwidth",
    "texlive-functan",
    "texlive-fundus-calligra",
    "texlive-fundus-cyr",
    "texlive-fundus-sueterlin",
    "texlive-fwlw",
    "texlive-g-brief",
    "texlive-gaceta",
    "texlive-galois",
    "texlive-gamebook",
    "texlive-garrigues",
    "texlive-garuda-c90",
    "texlive-gastex",
    "texlive-gatech-thesis",
    "texlive-gates",
    "texlive-gauss",
    "texlive-gb4e",
    "texlive-gcard",
    "texlive-gchords",
    "texlive-gcite",
    "texlive-gene-logic",
    "texlive-genealogy",
    "texlive-genmisc",
    "texlive-genmpage",
    "texlive-gentium",
    "texlive-gentium-tug",
    "texlive-gentle",
    "texlive-geometry",
    "texlive-geometry-de",
    "texlive-german",
    "texlive-germbib",
    "texlive-germkorr",
    "texlive-geschichtsfrkl",
    "texlive-getfiledate",
    "texlive-getoptk",
    "texlive-gfsartemisia",
    "texlive-gfsbaskerville",
    "texlive-gfsbodoni",
    "texlive-gfscomplutum",
    "texlive-gfsdidot",
    "texlive-gfsneohellenic",
    "texlive-gfsporson",
    "texlive-gfssolomos",
    "texlive-ghab",
    "texlive-gillcm",
    "texlive-gillius",
    "texlive-gincltex",
    "texlive-ginpenc",
    "texlive-gitinfo",
    "texlive-gloss",
    "texlive-glossaries",
    "texlive-glyphlist",
    "texlive-gmdoc",
    "texlive-gmdoc-enhance",
    "texlive-gmeometric",
    "texlive-gmiflink",
    "texlive-gmp",
    "texlive-gmutils",
    "texlive-gmverb",
    "texlive-gmverse",
    "texlive-gnu-freefont",
    "texlive-gnuplottex",
    "texlive-go",
    "texlive-gost",
    "texlive-gothic",
    "texlive-gradientframe",
    "texlive-grafcet",
    "texlive-graphics",
    "texlive-graphics-pln",
    "texlive-graphicx-psmin",
    "texlive-graphviz",
    "texlive-greek-fontenc",
    "texlive-greek-inputenc",
    "texlive-greekdates",
    "texlive-greektex",
    "texlive-greenpoint",
    "texlive-grfpaste",
    "texlive-grid",
    "texlive-grid-system",
    "texlive-gridset",
    "texlive-grotesq",
    "texlive-grverb",
    "texlive-gsftopk",
    "texlive-gtl",
    "texlive-gtrcrd",
    "texlive-gu",
    "texlive-guide-to-latex",
    "texlive-guitar",
    "texlive-guitarchordschemes",
    "texlive-guitlogo",
    "texlive-gustlib",
    "texlive-gustprog",
    "texlive-hacm",
    "texlive-hands",
    "texlive-hanging",
    "texlive-hanoi",
    "texlive-happy4th",
    "texlive-har2nat",
    "texlive-hardwrap",
    "texlive-harmony",
    "texlive-harnon-cv",
    "texlive-harpoon",
    "texlive-harvard",
    "texlive-harveyballs",
    "texlive-harvmac",
    "texlive-hatching",
    "texlive-hausarbeit-jura",
    "texlive-hc",
    "texlive-he-she",
    "texlive-helvetic",
    "texlive-hep",
    "texlive-hepnames",
    "texlive-hepparticles",
    "texlive-hepthesis",
    "texlive-hepunits",
    "texlive-here",
    "texlive-hexgame",
    "texlive-hf-tikz",
    "texlive-hfbright",
    "texlive-hfoldsty",
    "texlive-hhtensor",
    "texlive-histogr",
    "texlive-historische-zeitschrift",
    "texlive-hitec",
    "texlive-hletter",
    "texlive-hobby",
    "texlive-hobete",
    "texlive-horoscop",
    "texlive-hpsdiss",
    "texlive-hrefhide",
    "texlive-hrlatex",
    "texlive-hvfloat",
    "texlive-hvindex",
    "texlive-hypdvips",
    "texlive-hyper",
    "texlive-hypernat",
    "texlive-hyperref",
    "texlive-hyperref-docsrc",
    "texlive-hyperxmp",
    "texlive-hyph-utf8",
    "texlive-hyphen-afrikaans",
    "texlive-hyphen-ancientgreek",
    "texlive-hyphen-arabic",
    "texlive-hyphen-armenian",
    "texlive-hyphen-base",
    "texlive-hyphen-basque",
    "texlive-hyphen-bulgarian",
    "texlive-hyphen-catalan",
    "texlive-hyphen-chinese",
    "texlive-hyphen-coptic",
    "texlive-hyphen-croatian",
    "texlive-hyphen-czech",
    "texlive-hyphen-danish",
    "texlive-hyphen-dutch",
    "texlive-hyphen-english",
    "texlive-hyphen-esperanto",
    "texlive-hyphen-estonian",
    "texlive-hyphen-ethiopic",
    "texlive-hyphen-farsi",
    "texlive-hyphen-finnish",
    "texlive-hyphen-french",
    "texlive-hyphen-friulan",
    "texlive-hyphen-galician",
    "texlive-hyphen-georgian",
    "texlive-hyphen-german",
    "texlive-hyphen-greek",
    "texlive-hyphen-hungarian",
    "texlive-hyphen-icelandic",
    "texlive-hyphen-indic",
    "texlive-hyphen-indonesian",
    "texlive-hyphen-interlingua",
    "texlive-hyphen-irish",
    "texlive-hyphen-italian",
    "texlive-hyphen-kurmanji",
    "texlive-hyphen-latin",
    "texlive-hyphen-latvian",
    "texlive-hyphen-lithuanian",
    "texlive-hyphen-mongolian",
    "texlive-hyphen-norwegian",
    "texlive-hyphen-piedmontese",
    "texlive-hyphen-polish",
    "texlive-hyphen-portuguese",
    "texlive-hyphen-romanian",
    "texlive-hyphen-romansh",
    "texlive-hyphen-russian",
    "texlive-hyphen-sanskrit",
    "texlive-hyphen-serbian",
    "texlive-hyphen-slovak",
    "texlive-hyphen-slovenian",
    "texlive-hyphen-spanish",
    "texlive-hyphen-swedish",
    "texlive-hyphen-thai",
    "texlive-hyphen-turkish",
    "texlive-hyphen-turkmen",
    "texlive-hyphen-ukrainian",
    "texlive-hyphen-uppersorbian",
    "texlive-hyphen-welsh",
    "texlive-hyphenat",
    "texlive-hyphenex",
    "texlive-hyplain",
    "texlive-ibycus-babel",
    "texlive-ibygrk",
    "texlive-icsv",
    "texlive-idxcmds",
    "texlive-idxlayout",
    "texlive-ieeepes",
    "texlive-ifetex",
    "texlive-ifluatex",
    "texlive-ifmslide",
    "texlive-ifmtarg",
    "texlive-ifnextok",
    "texlive-ifoddpage",
    "texlive-ifplatform",
    "texlive-ifsym",
    "texlive-iftex",
    "texlive-ifthenx",
    "texlive-ifxetex",
    "texlive-iitem",
    "texlive-ijmart",
    "texlive-ijqc",
    "texlive-imac",
    "texlive-image-gallery",
    "texlive-imakeidx",
    "texlive-impatient",
    "texlive-impatient-fr",
    "texlive-impnattypo",
    "texlive-import",
    "texlive-imsproc",
    "texlive-imtekda",
    "texlive-incgraph",
    "texlive-inconsolata",
    "texlive-index",
    "texlive-initials",
    "texlive-inlinebib",
    "texlive-inlinedef",
    "texlive-inputtrc",
    "texlive-insbox",
    "texlive-installfont",
    "texlive-interactiveworkbook",
    "texlive-interfaces",
    "texlive-interpreter",
    "texlive-interval",
    "texlive-intro-scientific",
    "texlive-inversepath",
    "texlive-invoice",
    "texlive-ionumbers",
    "texlive-iopart-num",
    "texlive-ipaex",
    "texlive-ipaex-type1",
    "texlive-iso",
    "texlive-iso10303",
    "texlive-isodate",
    "texlive-isodoc",
    "texlive-isomath",
    "texlive-isonums",
    "texlive-isorot",
    "texlive-isotope",
    "texlive-issuulinks",
    "texlive-itnumpar",
    "texlive-iwhdp",
    "texlive-iwona",
    "texlive-jablantile",
    "texlive-jadetex",
    "texlive-jamtimes",
    "texlive-japanese",
    "texlive-japanese-otf",
    "texlive-japanese-otf-uptex",
    "texlive-jfontmaps",
    "texlive-jknapltx",
    "texlive-jlabels",
    "texlive-jmlr",
    "texlive-jmn",
    "texlive-jneurosci",
    "texlive-jpsj",
    "texlive-js-misc",
    "texlive-jsclasses",
    "texlive-junicode",
    "texlive-jura",
    "texlive-juraabbrev",
    "texlive-jurabib",
    "texlive-juramisc",
    "texlive-jurarsp",
    "texlive-jvlisting",
    "texlive-kantlipsum",
    "texlive-karnaugh",
    "texlive-kastrup",
    "texlive-kdgdocs",
    "texlive-kerkis",
    "texlive-kerntest",
    "texlive-keycommand",
    "texlive-keyreader",
    "texlive-keystroke",
    "texlive-keyval2e",
    "texlive-kix",
    "texlive-kixfont",
    "texlive-kluwer",
    "texlive-knitting",
    "texlive-knittingpattern",
    "texlive-knuth",
    "texlive-knuthotherfonts",
    "texlive-koma-moderncvclassic",
    "texlive-koma-script",
    "texlive-koma-script-examples",
    "texlive-koma-script-sfs",
    "texlive-kopka",
    "texlive-kotex-oblivoir",
    "texlive-kotex-plain",
    "texlive-kotex-utf",
    "texlive-kotex-utils",
    "texlive-kpathsea",
    "texlive-kpfonts",
    "texlive-ksfh_nat",
    "texlive-ktv-texdata",
    "texlive-kurier",
    "texlive-l2picfaq",
    "texlive-l2tabu",
    "texlive-l2tabu-english",
    "texlive-l2tabu-french",
    "texlive-l2tabu-italian",
    "texlive-l2tabu-spanish",
    "texlive-l3experimental",
    "texlive-l3kernel",
    "texlive-l3packages",
    "texlive-labbook",
    "texlive-labelcas",
    "texlive-labels",
    "texlive-lacheck",
    "texlive-lambda",
    "texlive-lambda-lists",
    "texlive-langcode",
    "texlive-lapdf",
    "texlive-lastpage",
    "texlive-latex",
    "texlive-latex-bib-ex",
    "texlive-latex-brochure",
    "texlive-latex-course",
    "texlive-latex-doc-ptr",
    "texlive-latex-fonts",
    "texlive-latex-git-log",
    "texlive-latex-graphics-companion",
    "texlive-latex-notes-zh-cn",
    "texlive-latex-referenz",
    "texlive-latex-tabellen",
    "texlive-latex-tds",
    "texlive-latex-veryshortguide",
    "texlive-latex-web-companion",
    "texlive-latex2e-help-texinfo",
    "texlive-latex2e-help-texinfo-spanish",
    "texlive-latex2man",
    "texlive-latex4wp",
    "texlive-latex4wp-it",
    "texlive-latexcheat",
    "texlive-latexcheat-esmx",
    "texlive-latexcheat-ptbr",
    "texlive-latexconfig",
    "texlive-latexdiff",
    "texlive-latexfileinfo-pkgs",
    "texlive-latexfileversion",
    "texlive-latexindent",
    "texlive-latexmk",
    "texlive-latexmp",
    "texlive-latexpand",
    "texlive-lato",
    "texlive-layaureo",
    "texlive-layouts",
    "texlive-lazylist",
    "texlive-lcd",
    "texlive-lcdftypetools",
    "texlive-lcg",
    "texlive-lcyw",
    "texlive-leading",
    "texlive-leaflet",
    "texlive-lecturer",
    "texlive-ledmac",
    "texlive-leftidx",
    "texlive-leipzig",
    "texlive-lengthconvert",
    "texlive-lettre",
    "texlive-lettrine",
    "texlive-levy",
    "texlive-lewis",
    "texlive-lexikon",
    "texlive-lfb",
    "texlive-lgreek",
    "texlive-lgrx",
    "texlive-lh",
    "texlive-lhcyr",
    "texlive-lhelp",
    "texlive-libertine",
    "texlive-libertine-type1",
    "texlive-libertineotf",
    "texlive-libgreek",
    "texlive-librarian",
    "texlive-librebaskerville",
    "texlive-librecaslon",
    "texlive-libris",
    "texlive-lilyglyphs",
    "texlive-limap",
    "texlive-linearA",
    "texlive-linegoal",
    "texlive-lineno",
    "texlive-linguex",
    "texlive-lipsum",
    "texlive-lisp-on-tex",
    "texlive-listbib",
    "texlive-listing",
    "texlive-listings",
    "texlive-listings-ext",
    "texlive-listliketab",
    "texlive-listofsymbols",
    "texlive-lithuanian",
    "texlive-liturg",
    "texlive-lkproof",
    "texlive-lm",
    "texlive-lm-math",
    "texlive-lmake",
    "texlive-lmextra",
    "texlive-locality",
    "texlive-localloc",
    "texlive-logbox",
    "texlive-logical-markup-utils",
    "texlive-logicpuzzle",
    "texlive-logpap",
    "texlive-logreq",
    "texlive-longnamefilelist",
    "texlive-loops",
    "texlive-lpic",
    "texlive-lplfitch",
    "texlive-lps",
    "texlive-lsc",
    "texlive-lshort-bulgarian",
    "texlive-lshort-chinese",
    "texlive-lshort-czech",
    "texlive-lshort-dutch",
    "texlive-lshort-english",
    "texlive-lshort-finnish",
    "texlive-lshort-french",
    "texlive-lshort-german",
    "texlive-lshort-italian",
    "texlive-lshort-japanese",
    "texlive-lshort-korean",
    "texlive-lshort-mongol",
    "texlive-lshort-persian",
    "texlive-lshort-polish",
    "texlive-lshort-portuguese",
    "texlive-lshort-russian",
    "texlive-lshort-slovak",
    "texlive-lshort-slovenian",
    "texlive-lshort-spanish",
    "texlive-lshort-thai",
    "texlive-lshort-turkish",
    "texlive-lshort-ukr",
    "texlive-lshort-vietnamese",
    "texlive-lstaddons",
    "texlive-ltablex",
    "texlive-ltabptch",
    "texlive-ltxdockit",
    "texlive-ltxfileinfo",
    "texlive-ltxindex",
    "texlive-ltxkeys",
    "texlive-ltxmisc",
    "texlive-ltxnew",
    "texlive-ltxtools",
    "texlive-lua-alt-getopt",
    "texlive-lua-check-hyphen",
    "texlive-lua-visual-debug",
    "texlive-lua2dox",
    "texlive-luabibentry",
    "texlive-luabidi",
    "texlive-luacode",
    "texlive-luaindex",
    "texlive-luainputenc",
    "texlive-luaintro",
    "texlive-lualatex-doc",
    "texlive-lualatex-doc-de",
    "texlive-lualatex-math",
    "texlive-lualibs",
    "texlive-luamplib",
    "texlive-luaotfload",
    "texlive-luasseq",
    "texlive-luatex",
    "texlive-luatexbase",
    "texlive-luatexja",
    "texlive-luatexko",
    "texlive-luatextra",
    "texlive-luaxml",
    "texlive-lxfonts",
    "texlive-ly1",
    "texlive-m-tx",
    "texlive-macqassign",
    "texlive-macros2e",
    "texlive-macroswap",
    "texlive-mafr",
    "texlive-magaz",
    "texlive-magyar",
    "texlive-mailing",
    "texlive-mailmerge",
    "texlive-makebarcode",
    "texlive-makebox",
    "texlive-makecell",
    "texlive-makecirc",
    "texlive-makecmds",
    "texlive-makedtx",
    "texlive-makeglos",
    "texlive-makeindex",
    "texlive-makeplot",
    "texlive-makeshape",
    "texlive-mandi",
    "texlive-manfnt",
    "texlive-manuscript",
    "texlive-margbib",
    "texlive-marginfix",
    "texlive-marginnote",
    "texlive-marvosym",
    "texlive-matc3",
    "texlive-matc3mem",
    "texlive-match_parens",
    "texlive-math-e",
    "texlive-mathabx",
    "texlive-mathabx-type1",
    "texlive-mathalfa",
    "texlive-mathastext",
    "texlive-mathcomp",
    "texlive-mathdesign",
    "texlive-mathdots",
    "texlive-mathexam",
    "texlive-mathmode",
    "texlive-mathpazo",
    "texlive-mathspec",
    "texlive-mathspic",
    "texlive-mattens",
    "texlive-maybemath",
    "texlive-mbenotes",
    "texlive-mcaption",
    "texlive-mceinleger",
    "texlive-mcite",
    "texlive-mciteplus",
    "texlive-mdframed",
    "texlive-mdputu",
    "texlive-mdsymbol",
    "texlive-mdwtools",
    "texlive-media9",
    "texlive-meetingmins",
    "texlive-memdesign",
    "texlive-memexsupp",
    "texlive-memoir",
    "texlive-memory",
    "texlive-mentis",
    "texlive-menu",
    "texlive-menukeys",
    "texlive-menukeys",
    "texlive-merriweather",
    "texlive-metafont",
    "texlive-metafont-beginners",
    "texlive-metago",
    "texlive-metalogo",
    "texlive-metaobj",
    "texlive-metaplot",
    "texlive-metapost",
    "texlive-metapost-examples",
    "texlive-metatex",
    "texlive-metauml",
    "texlive-method",
    "texlive-metre",
    "texlive-metrix",
    "texlive-mex",
    "texlive-mf2pt1",
    "texlive-mflogo",
    "texlive-mfnfss",
    "texlive-mfpic",
    "texlive-mfpic4ode",
    "texlive-mftinc",
    "texlive-mfware",
    "texlive-mh",
    "texlive-mhchem",
    "texlive-mhequ",
    "texlive-microtype",
    "texlive-microtype-de",
    "texlive-midnight",
    "texlive-midpage",
    "texlive-mil3",
    "texlive-miller",
    "texlive-minibox",
    "texlive-minifp",
    "texlive-minipage-marginpar",
    "texlive-miniplot",
    "texlive-minitoc",
    "texlive-minorrevision",
    "texlive-minted",
    "texlive-mintspirit",
    "texlive-minutes",
    "texlive-misc",
    "texlive-misc209",
    "texlive-mkgrkindex",
    "texlive-mkjobtexmf",
    "texlive-mkpattern",
    "texlive-mla-paper",
    "texlive-mlist",
    "texlive-mltex",
    "texlive-mmap",
    "texlive-mnotes",
    "texlive-mnsymbol",
    "texlive-moderncv",
    "texlive-moderntimeline",
    "texlive-modiagram",
    "texlive-modref",
    "texlive-modroman",
    "texlive-mongolian-babel",
    "texlive-monofill",
    "texlive-montex",
    "texlive-moreenum",
    "texlive-morefloats",
    "texlive-morehype",
    "texlive-moresize",
    "texlive-moreverb",
    "texlive-morewrites",
    "texlive-movie15",
    "texlive-mp3d",
    "texlive-mparhack",
    "texlive-mpattern",
    "texlive-mpcolornames",
    "texlive-mpgraphics",
    "texlive-mpman-ru",
    "texlive-mptopdf",
    "texlive-ms",
    "texlive-msc",
    "texlive-msg",
    "texlive-mslapa",
    "texlive-msu-thesis",
    "texlive-mtgreek",
    "texlive-multenum",
    "texlive-multi",
    "texlive-multibbl",
    "texlive-multibib",
    "texlive-multibibliography",
    "texlive-multicap",
    "texlive-multido",
    "texlive-multienv",
    "texlive-multiexpand",
    "texlive-multiobjective",
    "texlive-multirow",
    "texlive-munich",
    "texlive-musixguit",
    "texlive-musixtex",
    "texlive-musixtex-fonts",
    "texlive-musuos",
    "texlive-muthesis",
    "texlive-mversion",
    "texlive-mwcls",
    "texlive-mwe",
    "texlive-mweights",
    "texlive-mxedruli",
    "texlive-mychemistry",
    "texlive-mycv",
    "texlive-mylatexformat",
    "texlive-nag",
    "texlive-nameauth",
    "texlive-namespc",
    "texlive-nanumtype1",
    "texlive-natbib",
    "texlive-nath",
    "texlive-nature",
    "texlive-navigator",
    "texlive-ncclatex",
    "texlive-ncctools",
    "texlive-ncntrsbk",
    "texlive-nddiss",
    "texlive-needspace",
    "texlive-nestquot",
    "texlive-neuralnetwork",
    "texlive-newcommand",
    "texlive-newenviron",
    "texlive-newfile",
    "texlive-newlfm",
    "texlive-newpx",
    "texlive-newsletr",
    "texlive-newspaper",
    "texlive-newtx",
    "texlive-newunicodechar",
    "texlive-newvbtm",
    "texlive-newverbs",
    "texlive-nextpage",
    "texlive-nfssext-cfr",
    "texlive-nicefilelist",
    "texlive-niceframe",
    "texlive-nicetext",
    "texlive-nih",
    "texlive-nkarta",
    "texlive-nlctdoc",
    "texlive-noconflict",
    "texlive-noindentafter",
    "texlive-noitcrul",
    "texlive-nolbreaks",
    "texlive-nomencl",
    "texlive-nomentbl",
    "texlive-nonfloat",
    "texlive-nonumonpart",
    "texlive-nopageno",
    "texlive-norasi-c90",
    "texlive-nostarch",
    "texlive-notes",
    "texlive-notes2bib",
    "texlive-notoccite",
    "texlive-nowidow",
    "texlive-nox",
    "texlive-nrc",
    "texlive-ntgclass",
    "texlive-ntheorem",
    "texlive-ntheorem-vn",
    "texlive-nuc",
    "texlive-numberedblock",
    "texlive-numericplots",
    "texlive-numname",
    "texlive-numprint",
    "texlive-oberdiek",
    "texlive-objectz",
    "texlive-ocg-p",
    "texlive-ocgx",
    "texlive-ocherokee",
    "texlive-ocr-b",
    "texlive-ocr-b-outline",
    "texlive-ocr-latex",
    "texlive-octavo",
    "texlive-odsfile",
    "texlive-ofs",
    "texlive-ogham",
    "texlive-oinuit",
    "texlive-oldlatin",
    "texlive-oldstandard",
    "texlive-oldstyle",
    "texlive-omega",
    "texlive-omegaware",
    "texlive-onlyamsmath",
    "texlive-onrannual",
    "texlive-opcit",
    "texlive-opensans",
    "texlive-opteng",
    "texlive-optional",
    "texlive-ordinalpt",
    "texlive-orkhun",
    "texlive-oscola",
    "texlive-ot-tableau",
    "texlive-othello",
    "texlive-othelloboard",
    "texlive-otibet",
    "texlive-oubraces",
    "texlive-outline",
    "texlive-outliner",
    "texlive-outlines",
    "texlive-overpic",
    "texlive-pacioli",
    "texlive-pagecolor",
    "texlive-pagecont",
    "texlive-pagenote",
    "texlive-pagerange",
    "texlive-pageslts",
    "texlive-palatino",
    "texlive-paper",
    "texlive-papercdcase",
    "texlive-papermas",
    "texlive-papertex",
    "texlive-paracol",
    "texlive-paralist",
    "texlive-parallel",
    "texlive-paratype",
    "texlive-paresse",
    "texlive-parnotes",
    "texlive-parrun",
    "texlive-parselines",
    "texlive-parskip",
    "texlive-passivetex",
    "texlive-pas-cv",
    "texlive-patch",
    "texlive-patchcmd",
    "texlive-patgen",
    "texlive-patgen2-tutorial",
    "texlive-path",
    "texlive-pauldoc",
    "texlive-pawpict",
    "texlive-pax",
    "texlive-pb-diagram",
    "texlive-pbox",
    "texlive-pbsheet",
    "texlive-pdf-trans",
    "texlive-pdf14",
    "texlive-pdfcomment",
    "texlive-pdfcprot",
    "texlive-pdfcrop",
    "texlive-pdfjam",
    "texlive-pdfmarginpar",
    "texlive-pdfpages",
    "texlive-pdfscreen",
    "texlive-pdfslide",
    "texlive-pdfsync",
    "texlive-pdftex",
    "texlive-pdftex-def",
    "texlive-pdftools",
    "texlive-pdftricks",
    "texlive-pdftricks2",
    "texlive-pdfwin",
    "texlive-pdfx",
    "texlive-pecha",
    "texlive-pedigree-perl",
    "texlive-perception",
    "texlive-perltex",
    "texlive-permute",
    "texlive-persian-bib",
    "texlive-persian-modern",
    "texlive-petiteannonce",
    "texlive-petri-nets",
    "texlive-pfarrei",
    "texlive-pgf",
    "texlive-pgf-blur",
    "texlive-pgf-soroban",
    "texlive-pgf-umlsd",
    "texlive-pgfgantt",
    "texlive-pgfkeyx",
    "texlive-pgfmolbio",
    "texlive-pgfopts",
    "texlive-pgfplots",
    "texlive-phaistos",
    "texlive-philex",
    "texlive-philokalia",
    "texlive-philosophersimprint",
    "texlive-phonetic",
    "texlive-phonrule",
    "texlive-photo",
    "texlive-physics",
    "texlive-physymb",
    "texlive-piano",
    "texlive-picinpar",
    "texlive-pict2e",
    "texlive-pictex",
    "texlive-pictex2",
    "texlive-pictexsum",
    "texlive-piechartmp",
    "texlive-piff",
    "texlive-pigpen",
    "texlive-pinlabel",
    "texlive-pitex",
    "texlive-pittetd",
    "texlive-pkfix",
    "texlive-pkfix-helper",
    "texlive-pkuthss",
    "texlive-pl",
    "texlive-placeins",
    "texlive-placeins-plain",
    "texlive-plain",
    "texlive-plain-doc",
    "texlive-plainpkg",
    "texlive-plantslabels",
    "texlive-plari",
    "texlive-plates",
    "texlive-play",
    "texlive-plipsum",
    "texlive-plnfss",
    "texlive-plstmary",
    "texlive-plweb",
    "texlive-pmgraph",
    "texlive-pmx",
    "texlive-pnas2009",
    "texlive-poemscol",
    "texlive-poetrytex",
    "texlive-polski",
    "texlive-poltawski",
    "texlive-polyglossia",
    "texlive-polyglot",
    "texlive-polynom",
    "texlive-polynomial",
    "texlive-polytable",
    "texlive-postcards",
    "texlive-poster-mac",
    "texlive-powerdot",
    "texlive-powerdot-FUBerlin",
    "texlive-ppr-prv",
    "texlive-pracjourn",
    "texlive-preprint",
    "texlive-prerex",
    "texlive-present",
    "texlive-presentations",
    "texlive-presentations-en",
    "texlive-prettyref",
    "texlive-preview",
    "texlive-printlen",
    "texlive-proba",
    "texlive-probsoln",
    "texlive-procIAGssymp",
    "texlive-prodint",
    "texlive-productbox",
    "texlive-program",
    "texlive-progress",
    "texlive-progressbar",
    "texlive-properties",
    "texlive-proposal",
    "texlive-prosper",
    "texlive-protex",
    "texlive-protocol",
    "texlive-przechlewski-book",
    "texlive-ps2pkm",
    "texlive-psafm",
    "texlive-psbao",
    "texlive-pseudocode",
    "texlive-psfrag",
    "texlive-psfrag-italian",
    "texlive-psfragx",
    "texlive-psgo",
    "texlive-psizzl",
    "texlive-pslatex",
    "texlive-psnfss",
    "texlive-pspicture",
    "texlive-pst-2dplot",
    "texlive-pst-3d",
    "texlive-pst-3dplot",
    "texlive-pst-abspos",
    "texlive-pst-am",
    "texlive-pst-asr",
    "texlive-pst-bar",
    "texlive-pst-barcode",
    "texlive-pst-bezier",
    "texlive-pst-blur",
    "texlive-pst-bspline",
    "texlive-pst-calendar",
    "texlive-pst-circ",
    "texlive-pst-coil",
    "texlive-pst-cox",
    "texlive-pst-dbicons",
    "texlive-pst-diffraction",
    "texlive-pst-electricfield",
    "texlive-pst-eps",
    "texlive-pst-eucl",
    "texlive-pst-eucl-translation-bg",
    "texlive-pst-exa",
    "texlive-pst-fill",
    "texlive-pst-fit",
    "texlive-pst-fr3d",
    "texlive-pst-fractal",
    "texlive-pst-fun",
    "texlive-pst-func",
    "texlive-pst-gantt",
    "texlive-pst-geo",
    "texlive-pst-ghsb",
    "texlive-pst-gr3d",
    "texlive-pst-grad",
    "texlive-pst-graphicx",
    "texlive-pst-infixplot",
    "texlive-pst-jtree",
    "texlive-pst-knot",
    "texlive-pst-labo",
    "texlive-pst-layout",
    "texlive-pst-lens",
    "texlive-pst-light3d",
    "texlive-pst-magneticfield",
    "texlive-pst-math",
    "texlive-pst-mirror",
    "texlive-pst-node",
    "texlive-pst-ob3d",
    "texlive-pst-ode",
    "texlive-pst-optexp",
    "texlive-pst-optic",
    "texlive-pst-osci",
    "texlive-pst-pad",
    "texlive-pst-pdf",
    "texlive-pst-pdgr",
    "texlive-pst-platon",
    "texlive-pst-plot",
    "texlive-pst-poly",
    "texlive-pst-pulley",
    "texlive-pst-qtree",
    "texlive-pst-rubans",
    "texlive-pst-sigsys",
    "texlive-pst-slpe",
    "texlive-pst-solarsystem",
    "texlive-pst-solides3d",
    "texlive-pst-soroban",
    "texlive-pst-spectra",
    "texlive-pst-stru",
    "texlive-pst-support",
    "texlive-pst-text",
    "texlive-pst-thick",
    "texlive-pst-tools",
    "texlive-pst-tree",
    "texlive-pst-tvz",
    "texlive-pst-uml",
    "texlive-pst-vectorian",
    "texlive-pst-vowel",
    "texlive-pst-vue3d",
    "texlive-pst2pdf",
    "texlive-pstool",
    "texlive-pstools",
    "texlive-pstricks",
    "texlive-pstricks-add",
    "texlive-pstricks-examples",
    "texlive-pstricks-examples-en",
    "texlive-pstricks-tutorial",
    "texlive-pstricks_calcnotes",
    "texlive-psu-thesis",
    "texlive-psutils",
    "texlive-ptex",
    "texlive-ptex2pdf",
    "texlive-ptext",
    "texlive-ptptex",
    "texlive-punk",
    "texlive-punk-latex",
    "texlive-punknova",
    "texlive-purifyeps",
    "texlive-pxbase",
    "texlive-pxchfon",
    "texlive-pxcjkcat",
    "texlive-pxfonts",
    "texlive-pxgreeks",
    "texlive-pxjahyper",
    "texlive-pxpgfmark",
    "texlive-pxrubrica",
    "texlive-pxtxalfa",
    "texlive-python",
    "texlive-pythontex",
    "texlive-qcm",
    "texlive-qobitree",
    "texlive-qpxqtx",
    "texlive-qstest",
    "texlive-qsymbols",
    "texlive-qtree",
    "texlive-quattrocento",
    "texlive-quotchap",
    "texlive-quoting",
    "texlive-quotmark",
    "texlive-r_und_s",
    "texlive-raleway",
    "texlive-ran_toks",
    "texlive-randbild",
    "texlive-randomwalk",
    "texlive-randtext",
    "texlive-rccol",
    "texlive-rcs",
    "texlive-rcs-multi",
    "texlive-rcsinfo",
    "texlive-readarray",
    "texlive-realboxes",
    "texlive-realscripts",
    "texlive-rec-thy",
    "texlive-recipe",
    "texlive-recipecard",
    "texlive-rectopma",
    "texlive-recycle",
    "texlive-refcheck",
    "texlive-reflectgraphics",
    "texlive-refman",
    "texlive-refstyle",
    "texlive-regcount",
    "texlive-regexpatch",
    "texlive-register",
    "texlive-regstats",
    "texlive-relenc",
    "texlive-relsize",
    "texlive-reotex",
    "texlive-repeatindex",
    "texlive-resphilosophica",
    "texlive-resumecls",
    "texlive-resumemac",
    "texlive-reverxii",
    "texlive-revtex",
    "texlive-revtex4",
    "texlive-ribbonproofs",
    "texlive-rjlparshap",
    "texlive-rlepsf",
    "texlive-rmpage",
    "texlive-robustcommand",
    "texlive-robustindex",
    "texlive-roex",
    "texlive-romanbar",
    "texlive-romande",
    "texlive-romanneg",
    "texlive-romannum",
    "texlive-romansh",
    "texlive-rotating",
    "texlive-rotfloat",
    "texlive-rotpages",
    "texlive-roundbox",
    "texlive-rrgtrees",
    "texlive-rsc",
    "texlive-rsfs",
    "texlive-rsfso",
    "texlive-rterface",
    "texlive-rtkinenc",
    "texlive-rtklage",
    "texlive-ruhyphen",
    "texlive-russ",
    "texlive-rviewport",
    "texlive-rvwrite",
    "texlive-ryethesis",
    "texlive-sa-tikz",
    "texlive-sageep",
    "texlive-sanskrit",
    "texlive-sansmath",
    "texlive-sansmathaccent",
    "texlive-sansmathfonts",
    "texlive-sapthesis",
    "texlive-sasnrdisplay",
    "texlive-sauerj",
    "texlive-sauter",
    "texlive-sauterfonts",
    "texlive-savefnmark",
    "texlive-savesym",
    "texlive-savetrees",
    "texlive-scale",
    "texlive-scalebar",
    "texlive-scalerel",
    "texlive-schemabloc",
    "texlive-schemata",
    "texlive-scheme-basic",
    "texlive-scheme-context",
    "texlive-scheme-full",
    "texlive-scheme-gust",
    "texlive-scheme-medium",
    "texlive-scheme-minimal",
    "texlive-scheme-small",
    "texlive-scheme-tetex",
    "texlive-scheme-xml",
    "texlive-schulschriften",
    "texlive-schwalbe-chess",
    "texlive-sciposter",
    "texlive-screenplay",
    "texlive-scrjrnl",
    "texlive-sdrt",
    "texlive-secdot",
    "texlive-section",
    "texlive-sectionbox",
    "texlive-sectsty",
    "texlive-seetexk",
    "texlive-selectp",
    "texlive-selnolig",
    "texlive-semantic",
    "texlive-semaphor",
    "texlive-seminar",
    "texlive-semioneside",
    "texlive-sepfootnotes",
    "texlive-sepnum",
    "texlive-seqsplit",
    "texlive-serbian-apostrophe",
    "texlive-serbian-date-lat",
    "texlive-serbian-def-cyr",
    "texlive-serbian-lig",
    "texlive-serbianc",
    "texlive-setdeck",
    "texlive-setspace",
    "texlive-seuthesis",
    "texlive-sf298",
    "texlive-sffms",
    "texlive-sfg",
    "texlive-sfmath",
    "texlive-sgame",
    "texlive-shade",
    "texlive-shadethm",
    "texlive-shadow",
    "texlive-shadowtext",
    "texlive-shapepar",
    "texlive-shipunov",
    "texlive-shorttoc",
    "texlive-show2e",
    "texlive-showcharinbox",
    "texlive-showdim",
    "texlive-showexpl",
    "texlive-showhyphens",
    "texlive-showlabels",
    "texlive-showtags",
    "texlive-shuffle",
    "texlive-sidecap",
    "texlive-sidenotes",
    "texlive-sides",
    "texlive-silence",
    "texlive-simplecd",
    "texlive-simplecv",
    "texlive-simplewick",
    "texlive-simplified-latex",
    "texlive-simurgh",
    "texlive-sitem",
    "texlive-siunitx",
    "texlive-skak",
    "texlive-skaknew",
    "texlive-skb",
    "texlive-skdoc",
    "texlive-skeycommand",
    "texlive-skeyval",
    "texlive-skmath",
    "texlive-skrapport",
    "texlive-skull",
    "texlive-slantsc",
    "texlive-slideshow",
    "texlive-smalltableof",
    "texlive-smartdiagram",
    "texlive-smartref",
    "texlive-snapshot",
    "texlive-snotez",
    "texlive-songbook",
    "texlive-songs",
    "texlive-sort-by-letters",
    "texlive-soton",
    "texlive-soul",
    "texlive-sourcecodepro",
    "texlive-sourcesanspro",
    "texlive-spanglish",
    "texlive-spanish",
    "texlive-spanish-mx",
    "texlive-sparklines",
    "texlive-spath3",
    "texlive-spelling",
    "texlive-sphack",
    "texlive-spie",
    "texlive-splines",
    "texlive-splitbib",
    "texlive-splitindex",
    "texlive-spot",
    "texlive-spotcolor",
    "texlive-spreadtab",
    "texlive-spverbatim",
    "texlive-srbook-mem",
    "texlive-srcltx",
    "texlive-sseq",
    "texlive-stack",
    "texlive-stackengine",
    "texlive-stage",
    "texlive-standalone",
    "texlive-starfont",
    "texlive-startex",
    "texlive-statex",
    "texlive-statex2",
    "texlive-statistik",
    "texlive-staves",
    "texlive-stdclsdv",
    "texlive-stdpage",
    "texlive-steinmetz",
    "texlive-stellenbosch",
    "texlive-stex",
    "texlive-stix",
    "texlive-stmaryrd",
    "texlive-storebox",
    "texlive-storecmd",
    "texlive-stringstrings",
    "texlive-struktex",
    "texlive-sttools",
    "texlive-stubs",
    "texlive-sty2dtx",
    "texlive-suanpan",
    "texlive-subdepth",
    "texlive-subeqn",
    "texlive-subeqnarray",
    "texlive-subfig",
    "texlive-subfigmat",
    "texlive-subfigure",
    "texlive-subfiles",
    "texlive-subfloat",
    "texlive-substances",
    "texlive-substitutefont",
    "texlive-substr",
    "texlive-subsupscripts",
    "texlive-sudoku",
    "texlive-sudokubundle",
    "texlive-suftesi",
    "texlive-sugconf",
    "texlive-superiors",
    "texlive-supertabular",
    "texlive-susy",
    "texlive-svg",
    "texlive-svg-inkscape",
    "texlive-svgcolor",
    "texlive-svn",
    "texlive-svn-multi",
    "texlive-svn-prov",
    "texlive-svninfo",
    "texlive-swebib",
    "texlive-swimgraf",
    "texlive-syllogism",
    "texlive-symbol",
    "texlive-synctex",
    "texlive-synproof",
    "texlive-syntax",
    "texlive-syntrace",
    "texlive-synttree",
    "texlive-systeme",
    "texlive-t-angles",
    "texlive-t2",
    "texlive-tabfigures",
    "texlive-tableaux",
    "texlive-tablefootnote",
    "texlive-tableof",
    "texlive-tablists",
    "texlive-tablor",
    "texlive-tabls",
    "texlive-tabriz-thesis",
    "texlive-tabto-generic",
    "texlive-tabto-ltx",
    "texlive-tabu",
    "texlive-tabularborder",
    "texlive-tabularcalc",
    "texlive-tabularew",
    "texlive-tabulars-e",
    "texlive-tabulary",
    "texlive-tabvar",
    "texlive-tagging",
    "texlive-talk",
    "texlive-tamefloats",
    "texlive-tamethebeast",
    "texlive-tap",
    "texlive-tapir",
    "texlive-tcldoc",
    "texlive-tcolorbox",
    "texlive-tdclock",
    "texlive-tds",
    "texlive-tdsfrmath",
    "texlive-technics",
    "texlive-ted",
    "texlive-templates-fenn",
    "texlive-templates-sommer",
    "texlive-tengwarscript",
    "texlive-tensor",
    "texlive-termcal",
    "texlive-termlist",
    "texlive-tetex",
    "texlive-teubner",
    "texlive-tex",
    "texlive-tex-ewd",
    "texlive-tex-font-errors-cheatsheet",
    "texlive-tex-gyre",
    "texlive-tex-gyre-math",
    "texlive-tex-label",
    "texlive-tex-overview",
    "texlive-tex-ps",
    "texlive-tex-refs",
    "texlive-tex-virtual-academy-pl",
    "texlive-tex4ht",
    "texlive-texapi",
    "texlive-texbytopic",
    "texlive-texconfig",
    "texlive-texcount",
    "texlive-texdef",
    "texlive-texdiff",
    "texlive-texdirflatten",
    "texlive-texdoc",
    "texlive-texdraw",
    "texlive-texilikechaps",
    "texlive-texilikecover",
    "texlive-texinfo",
    "texlive-texlive-common",
    "texlive-texlive-cz",
    "texlive-texlive-de",
    "texlive-texlive-docindex",
    "texlive-texlive-en",
    "texlive-texlive-fr",
    "texlive-texlive-it",
    "texlive-texlive-pl",
    "texlive-texlive-ru",
    "texlive-texlive-scripts",
    "texlive-texlive-sr",
    "texlive-texlive-zh-cn",
    "texlive-texliveonfly",
    "texlive-texloganalyser",
    "texlive-texlogos",
    "texlive-texmate",
    "texlive-texments",
    "texlive-texpower",
    "texlive-texshade",
    "texlive-texsis",
    "texlive-textcase",
    "texlive-textfit",
    "texlive-textglos",
    "texlive-textgreek",
    "texlive-textmerg",
    "texlive-textopo",
    "texlive-textpath",
    "texlive-textpos",
    "texlive-texware",
    "texlive-tfrupee",
    "texlive-thailatex",
    "texlive-thalie",
    "texlive-theoremref",
    "texlive-thesis-titlepage-fhac",
    "texlive-thinsp",
    "texlive-thmbox",
    "texlive-thmtools",
    "texlive-threadcol",
    "texlive-threeddice",
    "texlive-threeparttable",
    "texlive-threeparttablex",
    "texlive-thumb",
    "texlive-thumbpdf",
    "texlive-thumbs",
    "texlive-thumby",
    "texlive-thuthesis",
    "texlive-ticket",
    "texlive-tie",
    "texlive-tikz-3dplot",
    "texlive-tikz-bayesnet",
    "texlive-tikz-cd",
    "texlive-tikz-dependency",
    "texlive-tikz-inet",
    "texlive-tikz-qtree",
    "texlive-tikz-timing",
    "texlive-tikzinclude",
    "texlive-tikzmark",
    "texlive-tikzorbital",
    "texlive-tikzpagenodes",
    "texlive-tikzpfeile",
    "texlive-tikzposter",
    "texlive-tikzscale",
    "texlive-tikzsymbols",
    "texlive-times",
    "texlive-timesht",
    "texlive-timetable",
    "texlive-timing-diagrams",
    "texlive-tipa",
    "texlive-tipa-de",
    "texlive-titlecaps",
    "texlive-titlefoot",
    "texlive-titlepages",
    "texlive-titlepic",
    "texlive-titleref",
    "texlive-titlesec",
    "texlive-titling",
    "texlive-tkz-base",
    "texlive-tkz-berge",
    "texlive-tkz-doc",
    "texlive-tkz-euclide",
    "texlive-tkz-fct",
    "texlive-tkz-graph",
    "texlive-tkz-kiviat",
    "texlive-tkz-linknodes",
    "texlive-tkz-orm",
    "texlive-tkz-tab",
    "texlive-tlc2",
    "texlive-tocbibind",
    "texlive-tocloft",
    "texlive-tocvsec2",
    "texlive-todo",
    "texlive-todonotes",
    "texlive-tokenizer",
    "texlive-toolbox",
    "texlive-tools",
    "texlive-topfloat",
    "texlive-toptesi",
    "texlive-totcount",
    "texlive-totpages",
    "texlive-tpic2pdftex",
    "texlive-tpslifonts",
    "texlive-tqft",
    "texlive-trajan",
    "texlive-tram",
    "texlive-translation-array-fr",
    "texlive-translation-arsclassica-de",
    "texlive-translation-biblatex-de",
    "texlive-translation-chemsym-de",
    "texlive-translation-dcolumn-fr",
    "texlive-translation-ecv-de",
    "texlive-translation-enumitem-de",
    "texlive-translation-europecv-de",
    "texlive-translation-filecontents-de",
    "texlive-translation-moreverb-de",
    "texlive-translation-natbib-fr",
    "texlive-translation-tabbing-fr",
    "texlive-translations",
    "texlive-tree-dvips",
    "texlive-treetex",
    "texlive-trfsigns",
    "texlive-trimspaces",
    "texlive-trivfloat",
    "texlive-trsym",
    "texlive-truncate",
    "texlive-tsemlines",
    "texlive-ttfutils",
    "texlive-tucv",
    "texlive-tufte-latex",
    "texlive-tugboat",
    "texlive-tugboat-plain",
    "texlive-tui",
    "texlive-turkmen",
    "texlive-turnstile",
    "texlive-turnthepage",
    "texlive-twoinone",
    "texlive-twoup",
    "texlive-txfonts",
    "texlive-txfontsb",
    "texlive-txgreeks",
    "texlive-type1cm",
    "texlive-typeface",
    "texlive-typehtml",
    "texlive-typeoutfileinfo",
    "texlive-typogrid",
    "texlive-uaclasses",
    "texlive-uadocs",
    "texlive-uafthesis",
    "texlive-ucdavisthesis",
    "texlive-ucharclasses",
    "texlive-ucs",
    "texlive-ucthesis",
    "texlive-udesoftec",
    "texlive-uebungsblatt",
    "texlive-uestcthesis",
    "texlive-uhc",
    "texlive-uiucredborder",
    "texlive-uiucthesis",
    "texlive-ukrhyph",
    "texlive-ulem",
    "texlive-ulqda",
    "texlive-ulthese",
    "texlive-umich-thesis",
    "texlive-uml",
    "texlive-umlaute",
    "texlive-umoline",
    "texlive-umthesis",
    "texlive-umtypewriter",
    "texlive-unamthesis",
    "texlive-underlin",
    "texlive-underoverlap",
    "texlive-underscore",
    "texlive-undolabl",
    "texlive-uni-wtal-ger",
    "texlive-uni-wtal-lin",
    "texlive-unicode-math",
    "texlive-unisugar",
    "texlive-units",
    "texlive-unitsdef",
    "texlive-universa",
    "texlive-unravel",
    "texlive-unswcover",
    "texlive-uothesis",
    "texlive-uowthesis",
    "texlive-uowthesistitlepage",
    "texlive-upca",
    "texlive-upmethodology",
    "texlive-upquote",
    "texlive-uptex",
    "texlive-uri",
    "texlive-url",
    "texlive-urlbst",
    "texlive-urwchancal",
    "texlive-usebib",
    "texlive-ushort",
    "texlive-uspatent",
    "texlive-ut-thesis",
    "texlive-utf8mex",
    "texlive-utopia",
    "texlive-uwmslide",
    "texlive-uwthesis",
    "texlive-vak",
    "texlive-vancouver",
    "texlive-variations",
    "texlive-varindex",
    "texlive-varisize",
    "texlive-varsfromjobname",
    "texlive-varwidth",
    "texlive-vaucanson-g",
    "texlive-vdmlisting",
    "texlive-velthuis",
    "texlive-venn",
    "texlive-venndiagram",
    "texlive-venturisadf",
    "texlive-verbasef",
    "texlive-verbatimbox",
    "texlive-verbatimcopy",
    "texlive-verbdef",
    "texlive-verbments",
    "texlive-verse",
    "texlive-version",
    "texlive-versions",
    "texlive-vertbars",
    "texlive-vhistory",
    "texlive-visualfaq",
    "texlive-vlna",
    "texlive-vmargin",
    "texlive-vntex",
    "texlive-vocaltract",
    "texlive-volumes",
    "texlive-voss-de",
    "texlive-vpe",
    "texlive-vruler",
    "texlive-vwcol",
    "texlive-wadalab",
    "texlive-wallpaper",
    "texlive-warning",
    "texlive-warpcol",
    "texlive-was",
    "texlive-wasy",
    "texlive-wasysym",
    "texlive-web",
    "texlive-webguide",
    "texlive-widetable",
    "texlive-williams",
    "texlive-withargs",
    "texlive-wnri",
    "texlive-wnri-latex",
    "texlive-wordlike",
    "texlive-wrapfig",
    "texlive-wsemclassic",
    "texlive-wsuipa",
    "texlive-xargs",
    "texlive-xbmc",
    "texlive-xcharter",
    "texlive-xcite",
    "texlive-xcjk2uni",
    "texlive-xcolor",
    "texlive-xcomment",
    "texlive-xcookybooky",
    "texlive-xdoc",
    "texlive-xdvi",
    "texlive-xecjk",
    "texlive-xecolor",
    "texlive-xecyr",
    "texlive-xeindex",
    "texlive-xepersian",
    "texlive-xesearch",
    "texlive-xetex",
    "texlive-xetex-def",
    "texlive-xetex-devanagari",
    "texlive-xetex-itrans",
    "texlive-xetex-pstricks",
    "texlive-xetex-tibetan",
    "texlive-xetexconfig",
    "texlive-xetexfontinfo",
    "texlive-xetexko",
    "texlive-xetexref",
    "texlive-xevlna",
    "texlive-xfor",
    "texlive-xgreek",
    "texlive-xhfill",
    "texlive-xifthen",
    "texlive-xii",
    "texlive-xint",
    "texlive-xits",
    "texlive-xkeyval",
    "texlive-xlop",
    "texlive-xltxtra",
    "texlive-xmlplay",
    "texlive-xmltex",
    "texlive-xmpincl",
    "texlive-xnewcommand",
    "texlive-xoptarg",
    "texlive-xpatch",
    "texlive-xpeek",
    "texlive-xpicture",
    "texlive-xpinyin",
    "texlive-xpunctuate",
    "texlive-xq",
    "texlive-xskak",
    "texlive-xstring",
    "texlive-xtab",
    "texlive-xunicode",
    "texlive-xwatermark",
    "texlive-xyling",
    "texlive-xymtex",
    "texlive-xypic",
    "texlive-xypic-tut-pt",
    "texlive-xytree",
    "texlive-yafoot",
    "texlive-yagusylo",
    "texlive-yannisgr",
    "texlive-yax",
    "texlive-ydoc",
    "texlive-yfonts",
    "texlive-yhmath",
    "texlive-york-thesis",
    "texlive-youngtab",
    "texlive-yplan",
    "texlive-ytableau",
    "texlive-zapfchan",
    "texlive-zapfding",
    "texlive-zed-csp",
    "texlive-zhmetrics",
    "texlive-zhnumber",
    "texlive-zhspacing",
    "texlive-ziffer",
    "texlive-zwgetfdate",
    "texlive-zwpagelayout",
    "texlive-zxjafbfont",
    "texlive-zxjafont",
    "texlive-zxjatype",
);

my @remlist = (
    "texlive-ascii",
    "texlive-biolinum-type1",
    "texlive-collection-documentation-arabic",
    "texlive-collection-documentation-base",
    "texlive-collection-documentation-bulgarian",
    "texlive-collection-documentation-chinese",
    "texlive-collection-documentation-czechslovak",
    "texlive-collection-documentation-dutch",
    "texlive-collection-documentation-english",
    "texlive-collection-documentation-finnish",
    "texlive-collection-documentation-french",
    "texlive-collection-documentation-german",
    "texlive-collection-documentation-italian",
    "texlive-collection-documentation-japanese",
    "texlive-collection-documentation-korean",
    "texlive-collection-documentation-mongolian",
    "texlive-collection-documentation-polish",
    "texlive-collection-documentation-portuguese",
    "texlive-collection-documentation-russian",
    "texlive-collection-documentation-serbian",
    "texlive-collection-documentation-slovenian",
    "texlive-collection-documentation-spanish",
    "texlive-collection-documentation-thai",
    "texlive-collection-documentation-turkish",
    "texlive-collection-documentation-ukrainian",
    "texlive-collection-documentation-vietnamese",
    "texlive-collection-langarmenian",
    "texlive-collection-langcroatian",
    "texlive-collection-langdanish",
    "texlive-collection-langdutch",
    "texlive-collection-langfinnish",
    "texlive-collection-langhebrew",
    "texlive-collection-langhungarian",
    "texlive-collection-langlatin",
    "texlive-collection-langlatvian",
    "texlive-collection-langlithuanian",
    "texlive-collection-langmongolian",
    "texlive-collection-langnorwegian",
    "texlive-collection-langswedish",
    "texlive-collection-langtibetan",
    "texlive-collection-langturkmen",
    "texlive-collection-langvietnamese",
    "texlive-collection-texinfo",
    "texlive-dvipdfm",
    "texlive-economic",
    "texlive-friulan",
    "texlive-gentium",
    "texlive-gmeometric",
    "texlive-grverb",
    "texlive-kopka",
    "texlive-lgrx",
    "texlive-libertine-type1",
    "texlive-libertineotf",
    "texlive-lmextra",
    "texlive-macqassign",
    "texlive-magyar",
    "texlive-multi",
    "texlive-polyglot",
    "texlive-psafm",
    "texlive-pstricks-tutorial",
    "texlive-romansh",
    "texlive-serbianc",
    "texlive-spanish",
    "texlive-thailatex",
    "texlive-timesht",
    "texlive-xbmc",
    "texlive-xmlplay",
);

foreach my $item (@dirlist) {
    unless (-d "../$item") {
	if ($options{'i'}) {
	    `cd ..; abf get $item`;
	}
	else {
	    print("$item: not checked out\n");
	}
    }
}

foreach my $spec (glob("../texlive-*/*.spec")) {
    open(IN, "<$spec");
    my $line = <IN>;
    if ($line =~ /# revision (\d+)/) {
	my $revision = $1;
	$spec =~ m/\.\.\/texlive-(.*)\//;
	my $name = $1;
	unless ($namerev{$name} || grep($_ eq "texlive-$name", @dirlist)) {
	    print("texlive-$name: not handled\n");
	}
	$namerev{$name} = $revision;
    }
    close(IN);
}

sub should_skip {
    my ($package) = @_;
    return 1 if (!$enable_asymptote && $package =~ /^asymptote/);
    return 1 if (!$enable_xindy && $package =~ /^xindy/);
    return 1 if ($with_system_lcdf && $package =~ /^lcdftypetools/);
    return 1 if ($with_system_psutils &&
		 ($package =~ /^psutils/ ||
		  $package =~ /^getafm/));
    return 1 if ($with_system_t1lib &&
		 $package =~ /^t1utils/);
    return 1 if ($package =~ /texworks/ ||
		 $package eq "texlive-msg-translations" ||
		 $package =~ /wintools/);
    return 1 if ($package =~ m/00texlive\./ ||
		 $package =~ m/texlive.infra/);
    return 0;
}

# Check only noarch packages
foreach my $package ($tlpdb->list_packages()) {
    next if should_skip($package);
    if ($package =~ /(.*)\.(.*)/) {
	my $platform = $2;
	if ($platform eq $arch) {
	    next;
        }
	else {
	    next if ($platform =~ /(armel|armhf|alpha|i386|mipsel|powerpc|sparc|x86_64)-linux/ ||
		     $platform =~ /(amd64|i386)-k?freebsd/ ||
		     $platform =~ /i386-cygwin/ ||
		     $platform =~ /(i386|amd64)-netbsd/ ||
		     $platform =~ /mips-irix/ ||
		     $platform =~ /powerpc-aix/ ||
		     $platform =~ /(i386|sparc|x86_64)-solaris/ ||
		     $platform =~ /(x86_64|universal)-darwin/ ||
		     $platform =~ /win32/);
	}
    }
    my $tlpobj = $tlpdb->get_package($package);
    my $revision = $tlpobj->{'revision'};
    $revision = "undef" unless ($revision);
    if (!defined($namerev{$package})) {
	print("texlive-$package: not packaged ($revision), required by ");
	my @requires = $tlpdb->needed_by($package);
	if ($#requires >= 0) {
	    print(join(" ", @requires));
	}
	else {
	    print("<<nothing>>");
	}
	print("\n");
	next;
    }
    if ($namerev{$package} ne $revision) {
	if ($options{'i'}) {
	    `cd ../texlive-$package; git pull`;
	    open(IN, "../texlive-$package/texlive-$package.spec");
	    my $line = <IN>;
	    close(IN);
	    if ($line =~ /# revision (\d+)/) {
		next if ($1 eq $revision);
	    }
	}
	print("texlive-$package: revision changed ($namerev{$package} -> $revision)\n");
    }
}

# Upstream may have deprecrated package
foreach my $package (keys(%namerev)) {
    next if ($tlpdb->get_package($package));
    next if grep (/$package/, @remlist);
    print("texlive-$package: not in texlive.tlpdb\n");
}
